@@ -10,12 +10,10 @@ CCF = ''
 def key(r: str, ccf: str) -> Optional[str]:
     urls = re.findall(r"https*://.*$", r)
     if len(urls) != 1:
-        print(ccf, urls, r)
         return None
     url = urls[0].replace(" ", "")
     search = re.search(r"https*://dblp\.uni-trier.de/(.+?)$", url)
     if search is None:
-        print(ccf, urls, r)
         return None
     return "/".join(search.group(1).split("/")[0:3])
 
@@ -29,6 +27,3 @@ CCF_B += [
     "db/conf/hotchips"
 ]
 CCF_C: list[str] = list(filter(None, (key(r, 'C') for r in CCF_C)))
-print(CCF_A)
-print(CCF_B)
-print(CCF_C)
